.. _tem:

Transformed Eulerian Mean diagnostics (``pyzome.tem``)
======================================================
Functions for computing Transformed Eulerian Mean (TEM) diagnostics.

Functions
---------
.. automodule:: pyzome.tem
   :members: